==> zio-aws-cloudformation_2.12-5.17.152.1-sources.jar: zio/aws/cloudformation/model/StackResourceDriftInformation.scala <==
package zio.aws.cloudformation.model
import zio.aws.cloudformation.model.primitives.Timestamp
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class StackResourceDriftInformation(
    stackResourceDriftStatus: zio.aws.cloudformation.model.StackResourceDriftStatus,
    lastCheckTimestamp: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation = {
    import StackResourceDriftInformation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation
      .builder()
      .stackResourceDriftStatus(stackResourceDriftStatus.unwrap)
      .optionallyWith(
        lastCheckTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastCheckTimestamp)
      .build()
  }
  def asReadOnly
      : zio.aws.cloudformation.model.StackResourceDriftInformation.ReadOnly =
    zio.aws.cloudformation.model.StackResourceDriftInformation
      .wrap(buildAwsValue())
}
object StackResourceDriftInformation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudformation.model.StackResourceDriftInformation =
      zio.aws.cloudformation.model.StackResourceDriftInformation(
        stackResourceDriftStatus,
        lastCheckTimestamp.map(value => value)
      )
    def stackResourceDriftStatus
        : zio.aws.cloudformation.model.StackResourceDriftStatus
    def lastCheckTimestamp: Option[Timestamp]
    def getStackResourceDriftStatus: ZIO[
      Any,
      Nothing,
      zio.aws.cloudformation.model.StackResourceDriftStatus
    ] = ZIO.succeed(stackResourceDriftStatus)
    def getLastCheckTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastCheckTimestamp", lastCheckTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation
  ) extends zio.aws.cloudformation.model.StackResourceDriftInformation.ReadOnly {
    override val stackResourceDriftStatus
        : zio.aws.cloudformation.model.StackResourceDriftStatus =
      zio.aws.cloudformation.model.StackResourceDriftStatus
        .wrap(impl.stackResourceDriftStatus())
    override val lastCheckTimestamp: Option[Timestamp] = scala
      .Option(impl.lastCheckTimestamp())
      .map(value => zio.aws.cloudformation.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation
  ): zio.aws.cloudformation.model.StackResourceDriftInformation.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cloudformation_2.12-5.20.42.1-sources.jar: zio/aws/cloudformation/model/StackResourceDriftInformation.scala <==
package zio.aws.cloudformation.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.cloudformation.model.primitives.Timestamp
import scala.jdk.CollectionConverters._
final case class StackResourceDriftInformation(
    stackResourceDriftStatus: zio.aws.cloudformation.model.StackResourceDriftStatus,
    lastCheckTimestamp: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation = {
    import StackResourceDriftInformation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation
      .builder()
      .stackResourceDriftStatus(stackResourceDriftStatus.unwrap)
      .optionallyWith(
        lastCheckTimestamp.map(value => Timestamp.unwrap(value): Instant)
      )(_.lastCheckTimestamp)
      .build()
  }
  def asReadOnly
      : zio.aws.cloudformation.model.StackResourceDriftInformation.ReadOnly =
    zio.aws.cloudformation.model.StackResourceDriftInformation
      .wrap(buildAwsValue())
}
object StackResourceDriftInformation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudformation.model.StackResourceDriftInformation =
      zio.aws.cloudformation.model.StackResourceDriftInformation(
        stackResourceDriftStatus,
        lastCheckTimestamp.map(value => value)
      )
    def stackResourceDriftStatus
        : zio.aws.cloudformation.model.StackResourceDriftStatus
    def lastCheckTimestamp: Optional[Timestamp]
    def getStackResourceDriftStatus: ZIO[
      Any,
      Nothing,
      zio.aws.cloudformation.model.StackResourceDriftStatus
    ] = ZIO.succeed(stackResourceDriftStatus)
    def getLastCheckTimestamp: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("lastCheckTimestamp", lastCheckTimestamp)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation
  ) extends zio.aws.cloudformation.model.StackResourceDriftInformation.ReadOnly {
    override val stackResourceDriftStatus
        : zio.aws.cloudformation.model.StackResourceDriftStatus =
      zio.aws.cloudformation.model.StackResourceDriftStatus
        .wrap(impl.stackResourceDriftStatus())
    override val lastCheckTimestamp: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.lastCheckTimestamp())
      .map(value => zio.aws.cloudformation.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.StackResourceDriftInformation
  ): zio.aws.cloudformation.model.StackResourceDriftInformation.ReadOnly =
    new Wrapper(impl)
}
